from typing import List, Optional

from sqlalchemy.orm import Session

from app.models.tag import Tag
from app.schemas.tag import TagCreate, TagUpdate


def get_tag(db: Session, tag_id: int) -> Optional[Tag]:
    return db.query(Tag).filter(Tag.id == tag_id).first()


def get_tag_by_name(db: Session, name: str, owner_id: int) -> Optional[Tag]:
    return db.query(Tag).filter(Tag.name == name, Tag.owner_id == owner_id).first()


def get_tags(
    db: Session, owner_id: int, skip: int = 0, limit: int = 100
) -> List[Tag]:
    return db.query(Tag).filter(Tag.owner_id == owner_id).offset(skip).limit(limit).all()


def get_tags_by_ids(db: Session, tag_ids: List[int], owner_id: int) -> List[Tag]:
    return db.query(Tag).filter(Tag.id.in_(tag_ids), Tag.owner_id == owner_id).all()


def create_tag(db: Session, tag_in: TagCreate, owner_id: int) -> Tag:
    db_tag = Tag(
        name=tag_in.name,
        owner_id=owner_id
    )
    db.add(db_tag)
    db.commit()
    db.refresh(db_tag)
    return db_tag


def update_tag(
    db: Session, db_obj: Tag, obj_in: TagUpdate
) -> Tag:
    update_data = obj_in.model_dump(exclude_unset=True)
    for field in update_data:
        setattr(db_obj, field, update_data[field])
    db.add(db_obj)
    db.commit()
    db.refresh(db_obj)
    return db_obj


def delete_tag(db: Session, tag_id: int) -> Tag:
    tag = db.query(Tag).filter(Tag.id == tag_id).first()
    db.delete(tag)
    db.commit()
    return tag